<?php

namespace App\Http\Controllers\Setting;

use App\Http\Controllers\Controller;
use App\Models\City;
use App\Models\State;
use App\MsgApp;
use \Yajra\Datatables\Datatables;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;

class CityController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = City::select('cities.id', 'cities.name', 'states.name as stateId' , 'cities.created_at')->join('states', 'cities.state_id', '=', 'states.id');
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = '<div class="d-flex"><a href="' . route('city.edit', $row->id) . '" class="edit btn btn-success btn-sm mr-2">Edit</a> <a href="' . route('city.destroy', $row->id) . '" data-method="delete" class="delete btn btn-danger btn-sm">Delete</a></div>';
                    return $actionBtn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        
        return view('setting.city.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $allState = State::select('name', 'id')->get();
        return view('setting.city.create', compact('allState'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make(
            $request->all(),
            [
                'name' => Str::replace(MsgApp::TABLE_NAME, 'cities', MsgApp::VAL_UNAME),
                'state_id' => Str::replace(MsgApp::TABLE_NAME, 'states', MsgApp::REQ_EXISTS),
            ],
            [
                'required' => ':attribute is required.',
                'regex' => ':attribute is invalid.',
            ],
            ['name' => 'Name']
        );
        if ($validator->fails()) {
            return Redirect::back()->withErrors($validator)->withInput($request->all());
        }
        City::saveData($request);
        return redirect('/setting/city/create')->with('success', MsgApp::SUCCESS_ADDED);
    }

    /**
     * Display the specified resource.
     */
    public function show($id)
    {
        City::where('id', $id)->delete();
        return redirect('/setting/city')->with('success', MsgApp::SUCCESS_DEL);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        $data = City::find($id);
        $allState = State::select('name', 'id')->get();
        return view('setting.city.edit', compact('allState', 'data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        $validator = Validator::make(
            $request->all(),
            [
                'name' => Str::replace(MsgApp::TABLE_NAME, 'cities,name,'.$id, MsgApp::VAL_UNAME),
                'state_id' => Str::replace(MsgApp::TABLE_NAME, 'states', MsgApp::REQ_EXISTS),
            ],
            [
                'required' => ':attribute is required.',
                'regex' => ':attribute is invalid.',
            ],
            ['name' => 'Name']
        );
        if ($validator->fails()) {
            return Redirect::back()->withErrors($validator)->withInput($request->all());
        }
        City::saveData($request, $id);
        return redirect('/setting/city')->with('success', MsgApp::SUCCESS_UPD);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
